package com.fluentadflowreactnativesdk

import android.util.Log
import android.view.View
import android.widget.FrameLayout
import com.facebook.react.bridge.ReadableMap
import com.facebook.react.uimanager.ThemedReactContext
import com.fluent.adflowsdk.adflow.FluentAdflowWidget
import com.fluent.adflowsdk.adflow.TelemetrySDK


class FluentAdFlowWidgetView(context: ThemedReactContext) : FrameLayout(context) {
  private var reactContext: ThemedReactContext?
  private lateinit var adflowWidget: FluentAdflowWidget

  init {
    this.reactContext = context
    adflowWidget = FluentAdflowWidget().init(this.reactContext)
    val sampleAdComponent: View = adflowWidget.getView()
    addView(sampleAdComponent)
  }

  public fun setParams(params: ReadableMap) {
    Log.d("FluentAdFlowWidgetView", "Setting params: " + params);
    val paramsMap = convertReadableMapToHashMap(params);

    // Remove the existing adFlowListener if present
    if (adflowWidget.adFlowListener != null) {
      adflowWidget.setAdFlowListener(null) // Clear the existing listener
    }

    // Set the new adFlowListener
    adflowWidget.setAdFlowListener(AdFlowListener(reactContext, paramsMap.getOrElse("viewId") { "" }))
    adflowWidget.setParams(paramsMap);
  }

  fun convertReadableMapToHashMap(readableMap: ReadableMap): HashMap<String, String> {
    val hashMap = HashMap<String, String>()
    val iterator = readableMap.keySetIterator()

    while (iterator.hasNextKey()) {
      val key = iterator.nextKey()
      val value = readableMap.getString(key)
      //print(", ${key}: ${value}")
      if (value != null) {
        hashMap[key] = value
      }
    }

    return hashMap
  }
  public fun setSdkWrapperName(wrapperName: String){
     TelemetrySDK.sdkWrapperName = wrapperName;
  }
  public fun setSdkWrapperVersion(wrapperVersion: String){
    TelemetrySDK.sdkWrapperVersion = wrapperVersion;
  }
}
